========================================
``psyclone.psyir.symbols.routinesymbol``
========================================

.. automodule:: psyclone.psyir.symbols.routinesymbol

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.symbols.routinesymbol


Classes
=======

- :py:class:`RoutineSymbol`:
  Symbol identifying a callable routine.


.. autoclass:: RoutineSymbol
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: RoutineSymbol
      :parts: 1
